#!/usr/bin/env python
"""These files contain the omniversion dependencies"""
from .file_info import FileMetadata
from .file_infos_list import FileInfosList
